==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/turtle/dialogs_pl.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Widzisz? To musi być ten telepatyczny żółw.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Ha, to on! Żółw o telepatycznych zdolnościach.")


dialogId("zel-m-fotky0", "font_small", "Well, I don`t know. Judging from those photos, it could be it.")
dialogStr("Ja tam nie wiem, ale wedle tych zdjęć to może być on.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Nie jestem pewna... a co z tymi zdolnościami telepatycznymi?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("W każdym razie musimy go wydobyć z tego pomieszczenia.")


dialogId("zel-v-zmistnosti1", "font_big", "Let`s take out that turtle.")
dialogStr("Wynieśmy stąd tego żółwia.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Co ty robisz?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Co ty zrobiłeś?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Co to miało znaczyć?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Dokąd płyniesz?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Co cię napadło?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Co się z tobą dzieje?")


dialogId("zel-m-nevim0", "font_small", "I don`t know...")
dialogStr("Nie wiem...")


dialogId("zel-m-nevim1", "font_small", "I can`t realize...")
dialogStr("Nic nie rozumiem...")


dialogId("zel-v-nevim0", "font_big", "I don`t know what`s happening to me...")
dialogStr("Nie wiem, co się ze mną dzieje...")


dialogId("zel-v-nevim1", "font_big", "I didn`t want to...")
dialogStr("Ja nie wiem, to się samo...")


dialogId("zel-v-cosedeje", "font_big", "What`s happening to us?")
dialogStr("Co się z nami dzieje?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Skąd to się bierze?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("To ten żółw!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("Ten żółw to robi!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("No to już nie ma wątpliwości - to on. To jego szukamy.")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Niechybnie jest to żółw, którego mieliśmy odnaleźć.")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Ta potwora!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Przestań, diabelskie nasienie!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("Mam tego dość!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Dobrze się bawisz?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tylko na rafie koralowej można znaleźć tyle dziwnych kształtów.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature`s wonders.")
dialogStr("Te korale to cuda natury.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Skąd się biorą wszystkie te dziwaczne kształty?")


dialogId("zel-m-jednoduse", "font_small", "It`s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("To proste - projektanci poziomów wymyślają trudne problemy, a ich narysowanie zostawiają grafikom.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Tym razem mamy za zadanie wynieść tego żółwia z pomieszczenia.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/turtle/dialogs_pl.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Widzisz? To musi być ten telepatyczny żółw.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Ha, to on! Żółw o telepatycznych zdolnościach.")


dialogId("zel-m-fotky0", "font_small", "Well, I don’t know. Judging from those photos, it could be it.")
dialogStr("Ja tam nie wiem, ale wedle tych zdjęć to może być on.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Nie jestem pewna... a co z tymi zdolnościami telepatycznymi?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("W każdym razie musimy go wydobyć z tego pomieszczenia.")


dialogId("zel-v-zmistnosti1", "font_big", "Let’s take out that turtle.")
dialogStr("Wynieśmy stąd tego żółwia.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Co ty robisz?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Co ty zrobiłeś?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Co to miało znaczyć?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Dokąd płyniesz?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Co cię napadło?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Co się z tobą dzieje?")


dialogId("zel-m-nevim0", "font_small", "I don’t know...")
dialogStr("Nie wiem...")


dialogId("zel-m-nevim1", "font_small", "I can’t realize...")
dialogStr("Nic nie rozumiem...")


dialogId("zel-v-nevim0", "font_big", "I don’t know what’s happening to me...")
dialogStr("Nie wiem, co się ze mną dzieje...")


dialogId("zel-v-nevim1", "font_big", "I didn’t want to...")
dialogStr("Ja nie wiem, to się samo...")


dialogId("zel-v-cosedeje", "font_big", "What’s happening to us?")
dialogStr("Co się z nami dzieje?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Skąd to się bierze?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("To ten żółw!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("Ten żółw to robi!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("No to już nie ma wątpliwości - to on. To jego szukamy.")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Niechybnie jest to żółw, którego mieliśmy odnaleźć.")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Ta potwora!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Przestań, diabelskie nasienie!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("Mam tego dość!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Dobrze się bawisz?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tylko na rafie koralowej można znaleźć tyle dziwnych kształtów.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature’s wonders.")
dialogStr("Te korale to cuda natury.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Skąd się biorą wszystkie te dziwaczne kształty?")


dialogId("zel-m-jednoduse", "font_small", "It’s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("To proste - projektanci poziomów wymyślają trudne problemy, a ich narysowanie zostawiają grafikom.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Tym razem mamy za zadanie wynieść tego żółwia z pomieszczenia.")
